@@ -38,6 +38,7 @@ using namespace DialogDsl::operators;
 #include "directorypairchooserwidget.h"
 #include "noticewidget.h"
 #include "passwordchooserwidget.h"
+#include "offlineonlywidget.h"
 
 class VaultCreationWizard::Private {
 public:
@@ -81,7 +82,10 @@ public:
                      },
                 step { passwordChooser() },
                 step { directoryPairChooser(DirectoryPairChooserWidget::SkipDevicePicker) },
-                step { activitiesChooser() }
+                step {
+                    activitiesChooser(),
+                    offlineOnlyChooser()
+                }
             }
         },
 
@@ -106,7 +110,8 @@ public:
                 step { directoryPairChooser() },
                 step {
                     cryfsCypherChooser(),
-                    activitiesChooser()
+                    activitiesChooser(),
+                    offlineOnlyChooser()
                 }
             }
         }
@@ -114,8 +119,8 @@ public:
 
     // to suggest the highest priority to the user as a starting value
     QMap<QString, int> priorities = {
-        { "encfs", 2 },
-        { "cryfs", 1 }
+        { "encfs", 1 },
+        { "cryfs", 2 }
     };
 
     template <typename ClickHandler>
